netapp_ontap.models.dcn_node_error API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_node_error`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnNodeErrorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnNodeError object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `count: Size GET`

    Number count of failed units.

    Example: 1

  `message: str GET`

    Error code describing the current condition.

    Example: 111411208

  `unit_type: str GET`

    The unit_type field of the dcn_node_error.

    Valid choices:

    - over_temperature
    - fan
    - psu
    - cpu
    - gpu
    - pcie
    - dimm
    - file_system
    - disk
    - system
    - memory
    - network